import type { AnyObject, Primitives } from './types';
type AllKeys<T> = T extends any ? keyof T : never;
type IndexValue<T, K extends PropertyKey, D = never> = T extends any ? (K extends keyof T ? T[K] : D) : never;
type PartialKeys<T, K extends keyof T> = Omit<T, K> & Partial<Pick<T, K>> extends infer O ? {
    [P in keyof O]: O[P];
} : never;
type DeepMerge<T> = [T] extends [Array<any>] ? {
    [K in keyof T]: DeepMerge<T[K]>;
} : [T] extends [Primitives] ? T : [T] extends [AnyObject] ? PartialKeys<{
    [K in AllKeys<T>]: DeepMerge<IndexValue<T, K>>;
}, never> : T;
type Spread<T, S> = S extends AnyObject[] ? [T, ...S] : [T, S];
type Merge<T, S> = DeepMerge<Spread<T, S>[number]>;
/**
 * deep merges provided objects by assigning the sources onto the target object passed as the first argument
 * @example
 * deepMerge({ a: 1, b: { c: 2 } }, { b: { d: 3 } })
 * // returns { a: 1, b: { c: 2, d: 3 } }
 */
export default function deepMerge<T extends AnyObject, S extends AnyObject[]>(target: T, ...sources: S): Merge<T, S>;
export {};
//# sourceMappingURL=deepMerge.d.ts.map