import type { StringDigit, Prettify } from './types';
type StringKeyOf<BaseType> = `${Extract<keyof BaseType, string | number>}`;
type Split<S extends string, Delimiter extends string> = S extends `${infer Head}${Delimiter}${infer Tail}` ? [Head, ...Split<Tail, Delimiter>] : S extends Delimiter ? [] : [S];
type GetWithPath<Default, BaseType, Keys extends readonly string[]> = Keys extends [] ? BaseType : Keys extends readonly [infer Head, ...infer Tail] ? GetWithPath<Default, PropertyOf<Default, BaseType, Extract<Head, string>>, Extract<Tail, string[]>> : Default;
type Strictify<Type> = Type | undefined;
type StrictPropertyOf<BaseType, Key extends keyof BaseType> = Record<string, any> extends BaseType ? string extends keyof BaseType ? Prettify<Strictify<BaseType[Key]>> : BaseType[Key] : BaseType[Key];
type ToPath<S extends string> = Split<S, '.'>;
type ConsistsOnlyOf<LongString extends string, Substring extends string> = LongString extends '' ? true : LongString extends `${Substring}${infer Tail}` ? ConsistsOnlyOf<Tail, Substring> : false;
type WithStringKeys<BaseType> = {
    [Key in StringKeyOf<BaseType>]: UncheckedIndex<BaseType, Key>;
};
type UncheckedIndex<T, U extends string | number> = [T] extends [Record<string | number, any>] ? T[U] : never;
type PropertyOf<Default, BaseType, Key extends string> = BaseType extends null | undefined ? undefined : Key extends keyof BaseType ? StrictPropertyOf<BaseType, Key> : BaseType extends [] | [unknown, ...unknown[]] ? Default : BaseType extends {
    [n: number]: infer Item;
    length: number;
} ? ConsistsOnlyOf<Key, StringDigit> extends true ? Prettify<Strictify<Item>> : Default : Key extends keyof WithStringKeys<BaseType> ? StrictPropertyOf<WithStringKeys<BaseType>, Key> : Default;
export type Get<BaseType, Path extends string | readonly string[], Default = unknown> = GetWithPath<Default, BaseType, Path extends string ? ToPath<Path> : Path>;
/**
 * returns the value from the specififed path from the provided object
 * @example
 * const obj = { a: { b: [1, 2, 3] } }
 * get('a.b.1', obj)
 * // returns 2
 * get(['a', 'b', '1'], obj)
 * // returns 2
 */
export default function get<Path extends string | readonly string[], Obj>(propPath: Path, obj: Obj): Get<Obj, Path>;
export {};
//# sourceMappingURL=get.d.ts.map