import type { AnyObject } from './types';
/**
 * groups values from the provided object based on the result of the provided key mapping function
 * @example
 * const obj = { a: 1, b: 2, c: 3 }
 * groupKeys(el => (el === 'a' ? 'aaa' : 'rest'), obj)
 * // returns {
 * //	aaa: { a: 1 },
 * //	rest: { b: 2, c: 3 },
 * // }
 */
export default function groupKeys<Obj extends AnyObject, Key extends PropertyKey>(mapper: (element: keyof Obj) => Key, obj: Obj): {
    [K in Key]: Record<keyof Obj, Obj[keyof Obj]>;
};
//# sourceMappingURL=groupKeys.d.ts.map