import type { AnyObject } from './types';
/**
 * constructs an object from the provided array of objects, grouped by the value of the specified key
 * @example
 * const arr = [
 * 	{ a: 'foo', b: 'bar' },
 * 	{ a: 'foo', b: 'baz' },
 * 	{ a: 'test', b: 'bab' },
 * ]
 * keyBy('a', arr)
 * // returns { foo: { a: 'foo', b: 'baz' }, test: { a: 'test', b: 'bab' } }
 */
export default function keyBy<Obj extends AnyObject, Prop extends keyof Obj>(prop: Prop, arr: Obj[]): {
    [P in Obj[Prop]]: Obj;
};
//# sourceMappingURL=keyBy.d.ts.map