import type { AnyFunction } from './types';
/**
 * memoizes the provided function so it returns cached results but only with one cache key
 * @example
 * const memoizedFunc = memoizeOne((val: number) => ({ current: val })
 *
 * const resultFor1 = memoizedFunc(1) // { current: 1 }
 * resultFor1 === memoizedFunc(1) // true
 * resultFor1 === memoizedFunc(1) // true
 *
 * const resultFor2 = memoizedFunc(2) // { current: 2 }
 * resultFor2 === memoizedFunc(2) // true
 * resultFor1 === memoizedFunc(1) // false
 */
export default function memoizeOne<T extends AnyFunction>(fn: T): (...args: Parameters<T>) => ReturnType<T>;
//# sourceMappingURL=memoizeOne.d.ts.map