import type { AnyFunction } from './types';
type KeyResolver<T extends AnyFunction> = (...args: Parameters<T>) => PropertyKey;
/**
 * memoizes the provided function so it returns cached results but based on the provided key resolver
 * @example
 * const memoizedFunc = memoizeWith(key => (key === 'a' ? key : 'bar'), (val: string) => ({ current: val }))
 * memoizedFunc('a') === memoizedFunc('a') // true
 * memoizedFunc('b') === memoizedFunc('c') // true
 */
export default function memoizeWith<T extends AnyFunction, K extends KeyResolver<T>>(keyResolver: K, func: T): T;
export {};
//# sourceMappingURL=memoizeWith.d.ts.map